
# THIS FILE IS GENERATED FROM pyedflib SETUP.PY
short_version = '0.1.23'
version = '0.1.23'
full_version = '0.1.23'
git_revision = '056ebf3243c958262edaab6bcd456f3c0fca2b75'
release = True

if not release:
    version = full_version
